/*********************************************************************
 * Licensed Materials - PropertyImpl of IBM                          *
 *                                                                   *
 * 5724-B88                                                          *
 *                                                                   *
 *  Copyright IBM Corp.  2001, 2002    All Rights Reserved.         *
 *                                                                   *
 * US Government Users Restricted Rights - Use, duplication or       *
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp. *
 *********************************************************************/

package com.ibm.websphere.query.base;


/**
	<P>The SelectQuery class represents a select query in the query framework. It is derived from 
	Query.
	
	<P>This class contains the order by (order by clause) part of a query, in addition to the
	attributes and behaviors inherited from base class Query, to describe a typical select query.
 */
public class SelectQuery extends Query implements ISelectQuery
{
  private IOrderBy orderBy;
  private ILimit limit;
  private ISelect select;
  private boolean cacheable = true;
  
  private String[] pageParams;

  /**
  	Creates a new SelectQuery instance, default constructor.
   */
  public SelectQuery()
  {
    super();
  }

  /**
  	Builds an order by string for the select query by delegating the operation to the given query
  	builder callback.
   */
  public String buildOrderByString(ISelectQueryCallback builder) throws QueryException
  {
    return builder.buildOrderBy(this);
  }
  public void buildOrderByString(ISelectQueryCallback builder, StringBuffer sb) throws QueryException
  {
    builder.buildOrderBy(this, sb);
  }

  /**
  	Builds an limit string for the select query by delegating the operation to the given query
  	builder callback.
   */
  public String buildLimitString(ISelectQueryCallback builder) throws QueryException
  {
    return builder.buildLimit(this);
  }
  public void buildLimitString(ISelectQueryCallback builder, StringBuffer sb) throws QueryException
  {
    builder.buildLimit(this, sb);
  }

  /**
  	Builds a query string for the select query.
   */
  public String buildString(ISelectQueryCallback builder) throws QueryException 
  {
     return builder.buildSelectQuery(this);
  }
  public void buildString(ISelectQueryCallback builder, StringBuffer sb) throws QueryException
  {
    builder.buildSelectQuery(this, sb);
  }
  /**
  	Tests for equality with the given object.
   */
  public boolean equals(Object o)
  {
    boolean eq = super.equals(o);

    if ((eq == true) && (o instanceof SelectQuery))
    {
      SelectQuery s = (SelectQuery) o;

      if (orderBy != null)
      {
        eq = orderBy.equals(s.orderBy);
      }
      else
      {
        eq = (s.orderBy == null);
      }
    }
    else
    {
      eq = false;
    }

    return eq;
  }
  /**
  	Returns the order by object.
   */
  public IOrderBy getOrderBy()
  {
    return orderBy;
  }
  /**
  	Computes a hash code for the select query.
   */
  public int hashCode()
  {
    int hashCode = super.hashCode();

    if (orderBy != null)
      hashCode = hashCode ^ orderBy.hashCode();

    return hashCode;
  }
  /**
  	Sets the order by of the select query.
   */
  public void setOrderBy(IOrderBy newOrderBy)
  {
    orderBy = newOrderBy;
  }
  /**
   * Gets the limit
   * @return Returns a ILimit
   */
  public ILimit getLimit()
  {
    return limit;
  }
  /**
   * Sets the limit
   * @param limit The limit to set
   */
  public void setLimit(ILimit limit)
  {
    this.limit = limit;
  }
  
  public String[] getPageParams()
  {
    return pageParams;
  }
  /** @param params: An string array of length 2,
   * params[0] = start, a string with the start of page
   * params[1] = end, a string with the end of page
   * Both should be convertible to Integers using Integer.parseInt()
   * However this method does not check this; nor does it enforce the length of the array.
   * Both are the caller's responsibility.
   */
  public void setPageParams(String[] params)
  {
    pageParams = params;
  }

  public boolean isCacheable()
  {
    return cacheable;
  }

  public void setCacheable(boolean b)
  {
    cacheable = b;
  }

  /**
   * @see com.ibm.websphere.query.base.ISelectQuery#getSelect()
   */
  public ISelect getSelect()
  {    
   return select;
  }

  /**
   * @see com.ibm.websphere.query.base.ISelectQuery#setSelect(com.ibm.websphere.query.base.ISelect)
   */
  public void setSelect(ISelect select)
  {
    this.select = select;
  }

  public String getName()
  {    
    return String.valueOf(hashCode());
  }
  
  public void setName(String tableName)
  {
  }
}
