package com.ibm.websphere.query.callbacks;

import java.util.Map;

import com.ibm.websphere.query.base.ArithmeticCondition;
import com.ibm.websphere.query.base.Attribute;
import com.ibm.websphere.query.base.Function;
import com.ibm.websphere.query.base.IArithmeticCondition;
import com.ibm.websphere.query.base.ILeftOperand;
import com.ibm.websphere.query.base.QueryException;
import com.ibm.websphere.query.base.Value;

/**
 * Licensed Materials - PropertyImpl of IBM. (C) COPYRIGHT International Business Machines Corp. 2002.
 */

/**
 * <P>The DB2SqlSelectQueryCallback class is a query builder callback that
 * adds limit functionality to DB2 queries. 
 */
public class CloudscapeSqlSelectQueryCallback extends SqlSelectQueryCallback
{
  public static final String SQL_QUERY_LIMITHEAD = "BULKFETCH= ";

  /**
   * Constructor for DB2SqlSelectQueryCallback.
   * @param nameMapping
   * @param typeMapping
   */
  public CloudscapeSqlSelectQueryCallback(Map nameMapping, Map typeMapping)
  {
    super(nameMapping, typeMapping);
  }

  /**
   * @see ISelectQueryCallback#buildArithmeticCondition(IArithmeticCondition)
   */
  public void buildArithmeticCondition(IArithmeticCondition arithmeticCondition, StringBuffer sb, Map metadata) throws QueryException
  {
    sb.append(SQL_QUERY_SPACE);
    String arithmeticOperation = arithmeticCondition.getArithmeticOperation();
    ILeftOperand[] arithmeticOperands = arithmeticCondition.getArithmeticConditionElements();
    for (int i = 0; i < arithmeticOperands.length; i++)
    {
      if (i > 0)
      {
        sb.append(SQL_QUERY_SPACE + arithmeticOperation + SQL_QUERY_SPACE);
      }
      if (arithmeticOperands[i] instanceof Attribute)
      {
        ((Attribute) arithmeticOperands[i]).buildString(this, sb);
      }
      else if (arithmeticOperands[i] instanceof Function)
      {
        ((Function) arithmeticOperands[i]).buildString(this, sb);
      }
      else if (arithmeticOperands[i] instanceof Value)
      {
        ((Value) arithmeticOperands[i]).buildString(this, sb);
      }
      else if (arithmeticOperands[i] instanceof ArithmeticCondition)
      {
        sb.append(SQL_QUERY_LEFTPAREN);
        ((ArithmeticCondition) arithmeticOperands[i]).buildString(this, sb);
        sb.append(SQL_QUERY_RIGHTPAREN);
      }
    }
    sb.append(SQL_QUERY_SPACE);
  }
}
