/*
 * LockType.java
 *
 * This file is part of the specification for the
 * Java Content Repository API
 */
package javax.jcr.lock;

/**
 * The lock types defined by the JCR standard.
 * <p>
 * <b>Level 2 only</b>
 * <p>
 * This interface defines the following lock type:
 * <UL>
 *    <LI>WRITE_LOCK
 * </UL>
 * Implementations of the JCR standard may support additional lock types.
 * @author Peeter Piegaze
 * @author Stefan Guggisberg
 */
public interface LockType {

    /**
     * The lock type <code>WRITE_LOCK</code>.
     * If a lock of this type is put on an item then any attempt to
     * write to the item (i.e., add a child node or property to a node, or
     * set the value of a property) will throw an <code>AccessDeniedException</code>
     * if the user of the ticket attempting to perform the operation is not an owner of
     * the lock.
     */
    public static final int WRITE_LOCK = 1;

    /**
     * Returns the numerical constant identifying this lock type. 
     * @return the numerical value
     * @see LockCapabilities#getSupportedLockTypes
     */
    public int getValue();

    /**
     * Returns the descriptive name of this lock type.
     * @return the name
     * @see LockCapabilities#getSupportedLockTypes
     */
    public String getName();
}

