/*
 * VetoableEventListener.java
 *
 * This file is part of the specification for the
 * Java Content Repository API
 */
package javax.jcr.observation;

/**
 * A vetoable event listener.
 * <p>
 * <b>Level 2 only</b>
 * <p>
 * A <code>VetoableEventListener</code> can be
 * registered via the <code>{@link javax.jcr.observation.ObservationManager}</code> object.
 * Vetoable event listeners may veto the action that the events represent. If an
 * event is vetoed, the corresponding action is forbidden by the repository.
 * Vetoable listeners are notified synchronously, and see events prior to the
 * repository acting upon them. A vetoable listener only sees events for which
 * the ticket that registered it has sufficient access rights.
 * <p>
 * To veto an event, a class implementing the <code>VetoableListener</code>
 * interface returns true from the <code>onEvent</code> method. If this happens
 * during a transaction, the transaction is rolled back. If multiple vetoable
 * listeners are registered, the first listener to veto an event causes the
 * original operation to fail. No other vetoable listener is invoked.
 *
 * @author tima, ppiegaze
 */
public interface VetoableEventListener {

    /**
     * Performs some action upon receipt of the event. Returning
     * <code>false</code> will cause the operation in question to proceed,,
     * returning false will veto the operation in quetion.
     * @param event
     * @return <code>true</code> to veto, <code>false</code> to proceed
     */
    public boolean onEvent(Event event);
}
