/*
 * QueryLanguage.java
 *
 * This file is part of v0.12 of the specification for the
 * Java Content Repository API
 */
package javax.jcr.query;

/**
 * This interface encapsulates methods for the management of search query languages.
 * Provides methods for the creation and retrieval of query language.
 *
 */
public interface QueryLanguage
{

  public static final int JCRQL_SSES = 0;
  public static final int XPATH = 1;
  public static final int[] SUPPORTED_LANGUAGE_VALUES = { 1 };

  /**
   * Returns the value of the query language.
   *
   * @return An <code>int</code> identifier of the language.
   */
  public int getValue();

  /**
   * Returns a string of query language name. The string should consist of two parts. 
   * The first identifying the main query language, the second identifying the full-
   * text search language embedded.
   * At minimum, the implementation must support <code>JCRQL</code> with the <i>Simple 
   * Search-Engine Syntax</i> (<code>SSES</code>) embedded in the <code>SEARCH</code> 
   * clause. The string identifier for this language is <code>JCRQL-SSES</code>.
   * <p>
   * Optionally, an implementation may support other embedded full-text
   * languages and/or other main query languages. Possible examples might be
   * <code>JCRQL-Fulcrum_SearchSQL</code> and <code>XPATH</code>.
   *
   * @return A string.
   */
  public String getName();

}
