/*
 * QueryResult.java
 *
 * This file is part of the v0.12 specification for the
 * Java Content Repository API
 */
package javax.jcr.query;

import javax.jcr.Node;
import javax.jcr.Property;

/**
 * A QueryResult object. Returned by {@link javax.jcr.query.Query#execute()
 * Query.execute()}
 *
 * @author Peeter Piegaze
 */
public interface QueryResult {

    /**
     * Returns a <code>Node</code> meeting the search criteria.
     *
     * @return a Node
     */
    public Node getNode();

    /**
     * If the query executed included a full text search clause then this method
     * returns a property whose value matched the text search.
     *
     * @return a Property or <code>null</code> if the query contains no SEARCH clause. 
     */
    public Property getProperty();

    /**
     * Returns the UUID of the matching node.
     *
     * @param item The item to test for membership in the result set.
     *
     * @return a <code>String</code> or <code>null</code> if the node does not have a
     * UUID.
     */
    public String getUUID();
    
	/**
	 * Returns an array of strings representing the paths of the matching node.
	 *
	 * @return an <code>Array</code>.
	 */
	public String[] getNodePaths();
	
	/**
	 * Returns the name of the property returned by the getProperty() method.
	 *
	 * @param item The item to test for membership in the result set.
	 *
	 * @return a <code>String</code> or <code>null</code> if the query does not
	 * contain a SEARCH clause.
	 */
	public String getPropertyName();

	/**
	 * Returns an integer representing the relevance of this <code>QueryResult</code>.
	 * The returned integer must be equal to or greater than zero. Zero should be 
	 * returned if score is not supported.
	 *
	 * @return a <code>int</code> or <code>0</code> if score does not exist.
	 */
	public int getScore();


}
